<?php
 /**
 * Plugin Name: Gutenform
 * Description: Forms builder for gutenberg.
 * Plugin URI: https://wpmet.com/plugin/gutenform/
 * Author: Wpmet
 * Version: 1.0.0
 * Author URI: https://wpmet.com/
 * License: GPL-3.0-or-later
 * License URI: https://www.gnu.org/licenses/gpl-3.0.html
 *
 * Text Domain: gutenform
 * Domain Path: /languages
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

/**
 * Registers the block using the metadata loaded from the `block.json` file.
 * Behind the scenes, it registers also all assets so they can be enqueued
 * through the block editor in the corresponding context.
 *
 * @see https://developer.wordpress.org/reference/functions/register_block_type/
 */

final class Gutenform {
	protected $option_key = 'gutenform_entries';

	public function __construct() {
		add_action( 'init', [$this, 'gutenform_gutenform_block_init']);
		add_action('wp_ajax_save_frontend_form_data', [$this, 'save_frontend_form_data']);
		add_action('wp_ajax_nopriv_save_frontend_form_data', [$this, 'save_frontend_form_data']);
		add_action('wp_enqueue_scripts', [$this, 'enqueue_frontend_assets']);
		add_action( 'admin_menu', [$this, 'add_admin_menu'] );
	}

	public function gutenform_gutenform_block_init() {
		register_block_type( __DIR__ . '/build' );
	}

	public function save_frontend_form_data() {
		// Get the form data from the AJAX request
		$nonce = isset($_POST['nonce']) ? sanitize_text_field($_POST['nonce']) : '';
		$name = isset($_POST['name']) ? sanitize_text_field($_POST['name']) : '';
		$email = isset($_POST['email']) ? sanitize_email($_POST['email']) : '';
		$message = isset($_POST['message']) ? sanitize_textarea_field($_POST['message']) : '';

		// verify nonce
		if( empty($nonce) || ! wp_verify_nonce($nonce, 'gutenform_nonce_action') ) {
			wp_send_json_error(esc_html__('Invalid nonce', 'gutenform'));
		}

		// check if name is empty
		if (empty($name)) {
			wp_send_json_error(esc_html__('Name is required', 'gutenform'));
		}

		// check if email is empty
		if (empty($email)) {
			wp_send_json_error(esc_html__('Email is required', 'gutenform'));
		}

		// check if message is empty
		if (empty($message)) {
			wp_send_json_error(esc_html__('Message is required', 'gutenform'));
		}

		$entry[] = array(
			'name' => esc_html($name),
			'email' => esc_html($email),
			'message' => esc_html($message),
		);
	
		if (!get_option($this->option_key)) {
			add_option($this->option_key, maybe_serialize($entry));
		} else {
			$saved_entries = get_option($this->option_key);
			$saved_entries = maybe_unserialize($saved_entries);
			$saved_entries[] = $entry[0];
			$entry = $saved_entries;
			update_option($this->option_key,  maybe_serialize($entry));
		}
	
		// Send a success response
		wp_send_json_success(esc_html__('Form data saved successfully!', 'gutenform'));

		wp_die();
	}
	
	public function enqueue_frontend_assets() {
		wp_enqueue_script('jquery');
		// Pass necessary data to the form script
		wp_localize_script('create-block-gutenform-view-script', 'gutenform_data', array(
			'ajaxurl' => admin_url('admin-ajax.php'),
			'nonce'   => wp_create_nonce('gutenform_nonce_action'),
		));
	}
	
	public function add_admin_menu() {
		add_menu_page(
			esc_html__( 'Guten Form', 'gutenform' ),
			esc_html__( 'Guten Form', 'gutenform' ),
			'manage_options',
			'gutenform',
			[$this, 'admin_menu_callback'],
			'dashicons-format-aside',
			20
		);
	}

	public function admin_menu_callback() {
		if(!current_user_can('manage_options')) {
			return;
		}

		$data = get_option($this->option_key);
		$data = maybe_unserialize($data);
		if ($data) {
			?>
			<h1><?php echo esc_html__('Guten Form Entries', 'gutenform'); ?></h1>
			<table style="width:100%; border:1px solid black">
				<thead>
					<tr style="text-align:center">
						<th style="border-bottom:1px solid black"><?php echo esc_html__('Item', 'gutenform'); ?></th>
						<th style="border-bottom:1px solid black"><?php echo esc_html__('Name', 'gutenform'); ?></th>
						<th style="border-bottom:1px solid black"><?php echo esc_html__('Email', 'gutenform'); ?></th>
						<th style="border-bottom:1px solid black"><?php echo esc_html__('Message', 'gutenform'); ?></th>
					</tr>
				</thead>
				<tbody>
					<?php
					foreach ($data as $key => $value) {
						?>
						<tr style="text-align:center">
							<td><?php echo esc_attr($key); ?></td>
							<td><?php echo esc_attr($value['name']); ?></td>
							<td><?php echo esc_attr($value['email']); ?></td>
							<td><?php echo esc_attr($value['message']); ?></td>
						</tr>
						<?php
					}
					?>
				</tbody>
			</table>
			<?php
		} else {
			?>
			<h1><?php echo esc_html__('Guten Form Entries', 'gutenform'); ?></h1>
			<p><?php echo esc_html__('No data found', 'gutenform'); ?></p>
			<?php
		}
	}
}

/**
 * Kickoff the plugin
 *
 * @since 0.1.0
 */
new Gutenform();




